==> libgphoto2-2.5.2.tar.xz: libgphoto2-api.html/gphoto2-camera_8c.js <==
var gphoto2-camera_8c =
[
    [ "_CameraPrivateCore", "struct__CameraPrivateCore.html", "struct__CameraPrivateCore" ],
    [ "_", "gphoto2-camera_8c.html#a32a3cf3d9dd914f5aeeca5423c157934", null ],
    [ "bindtextdomain", "gphoto2-camera_8c.html#add6dfc1077058ff26d79cdb18099d58a", null ],
    [ "CAMERA_UNUSED", "gphoto2-camera_8c.html#ac05b040056bfb8e0517570d4fd87eb1e", null ],
    [ "CHECK_CLOSE", "gphoto2-camera_8c.html#a8807273e062a649fe96c14f54e436bca", null ],
    [ "CHECK_INIT", "gphoto2-camera_8c.html#a8501471508eb438eb07e9cf034dc498c", null ],
    [ "CHECK_NULL", "gphoto2-camera_8c.html#a31f5b59ba0bbc5f65f733ef299e2533d", null ],
    [ "CHECK_OPEN", "gphoto2-camera_8c.html#a4954f9a8b7eaf2df232babe91f93fca7", null ],
    [ "CHECK_RESULT_OPEN_CLOSE", "gphoto2-camera_8c.html#a2413621dbe10bd9d91fdd5fd82c81618", null ],
    [ "CR", "gphoto2-camera_8c.html#a7de1aba49ce9fb5d84464417da3352e6", null ],
    [ "CRS", "gphoto2-camera_8c.html#abe944d32d0d1d16ab7519111476a8b57", null ],
    [ "CRSL", "gphoto2-camera_8c.html#a7fb0a84c4d54825143b3eee22e81d3ce", null ],
    [ "dcgettext", "gphoto2-camera_8c.html#a115dd6a6dd9d7a249f6374a7c06deef5", null ],
    [ "dgettext", "gphoto2-camera_8c.html#ad24abc7110e1bdf384dc2ef2b63e5d07", null ],
    [ "gettext", "gphoto2-camera_8c.html#a83b8be0887dede025766d25e2bb884c6", null ],
    [ "N_", "gphoto2-camera_8c.html#a75278405e7f034d2b1af80bfd94675fe", null ],
    [ "textdomain", "gphoto2-camera_8c.html#a5f80e8482ab93869489531a8c7ce7006", null ],
    [ "gp_camera_autodetect", "gphoto2-camera_8c.html#ae7b6050bb4bc7a697f9e07253c27710f", null ],
    [ "gp_camera_capture", "gphoto2-camera_8c.html#a8fa6903e3bf0ab26edc4e915512aa44f", null ],
    [ "gp_camera_capture_preview", "gphoto2-camera_8c.html#accaa70d614800dac941e543187c9712d", null ],
    [ "gp_camera_exit", "gphoto2-camera_8c.html#a6f19c4ea385641fb972e779badf48ae1", null ],
    [ "gp_camera_file_delete", "gphoto2-camera_8c.html#a456172175ee1829ef172ee9c747e850d", null ],
    [ "gp_camera_file_get", "gphoto2-camera_8c.html#a262b1bc840d62b12605e3acc543f714d", null ],
    [ "gp_camera_file_get_info", "gphoto2-camera_8c.html#adda54321b1947b711d345936041f80c7", null ],
    [ "gp_camera_file_read", "gphoto2-camera_8c.html#a1c1ad4e0cc48fec22aaddbba147975c8", null ],
    [ "gp_camera_file_set_info", "gphoto2-camera_8c.html#a1a66b26a0456f3d265051c4018f67208", null ],
    [ "gp_camera_folder_delete_all", "gphoto2-camera_8c.html#a0c61c3d62a6bb6daecbadbffa06cf3fb", null ],
    [ "gp_camera_folder_list_files", "gphoto2-camera_8c.html#a0cdf2043359617d5132665c36fc557d0", null ],
    [ "gp_camera_folder_list_folders", "gphoto2-camera_8c.html#a7dc2b5ed66b61b881caf7436cb05ded0", null ],
    [ "gp_camera_folder_make_dir", "gphoto2-camera_8c.html#a6b6669216aeae67304649edd42db605d", null ],
    [ "gp_camera_folder_put_file", "gphoto2-camera_8c.html#aa3dd64d491735a55bcab15d41b9113c3", null ],
    [ "gp_camera_folder_remove_dir", "gphoto2-camera_8c.html#a11f3855eef4f009701b008908fc78608", null ],
    [ "gp_camera_free", "gphoto2-camera_8c.html#a78ae1a19cc0fb4d94026f82497381124", null ],
    [ "gp_camera_get_abilities", "gphoto2-camera_8c.html#a240f8cc35944b01cce71609c265fda3a", null ],
    [ "gp_camera_get_about", "gphoto2-camera_8c.html#a0a46cbd79e1a634acebec4380cee6c5b", null ],
    [ "gp_camera_get_config", "gphoto2-camera_8c.html#ae87f24abbc6ee895867331c64e6986cf", null ],
    [ "gp_camera_get_manual", "gphoto2-camera_8c.html#a32cfd1eaec837dd43676eb211fa68cdb", null ],
    [ "gp_camera_get_port_info", "gphoto2-camera_8c.html#a969c10fd16501f62f0e3a276d237764a", null ],
    [ "gp_camera_get_port_speed", "gphoto2-camera_8c.html#a068405c418270c7c63ab9fdc3c0ae620", null ],
    [ "gp_camera_get_storageinfo", "gphoto2-camera_8c.html#ad5add695de4a33b6c5cbb8be32bf9af7", null ],
    [ "gp_camera_get_summary", "gphoto2-camera_8c.html#a7a2b16620e8dcd0efbd6f767188d9162", null ],
    [ "gp_camera_init", "gphoto2-camera_8c.html#ab0e3da4a22b7b71ec36e58157c868a9e", null ],
    [ "gp_camera_new", "gphoto2-camera_8c.html#ad89d6ee1c35f5ee399e89ecaeac6bd61", null ],
    [ "gp_camera_ref", "gphoto2-camera_8c.html#a449781f840d1a82e56f424d33371c511", null ],
    [ "gp_camera_set_abilities", "gphoto2-camera_8c.html#a95f595a6d9bfe68d99419a0087363f89", null ],
    [ "gp_camera_set_config", "gphoto2-camera_8c.html#a0b289e071be43bfeb6e65757cc274dbf", null ],
    [ "gp_camera_set_port_info", "gphoto2-camera_8c.html#a87bb8878064d7c4a98f1be7cedf7fd3c", null ],
    [ "gp_camera_set_port_speed", "gphoto2-camera_8c.html#a0fc2c594397f144a134074757e9dfab1", null ],
    [ "gp_camera_set_timeout_funcs", "gphoto2-camera_8c.html#af2e448cda5a2a1637d497fec7b89c44f", null ],
    [ "gp_camera_start_timeout", "gphoto2-camera_8c.html#a640b436ef19db8154283cc3044fb1d0a", null ],
    [ "gp_camera_stop_timeout", "gphoto2-camera_8c.html#a6d95c83814161ccd8f4cc1e86233c9d4", null ],
    [ "gp_camera_trigger_capture", "gphoto2-camera_8c.html#a5d5649f8c672a52800d0723bf29f33fa", null ],
    [ "gp_camera_unref", "gphoto2-camera_8c.html#a6027cb54859c035ce943cf1c3e06121a", null ],
    [ "gp_camera_wait_for_event", "gphoto2-camera_8c.html#a6a3aa30acd4bbe74087ce0fbcb9ea3a9", null ]
];

==> libgphoto2_2.5.27.orig.tar.xz: libgphoto2-api.html/gphoto2-camera_8c.js <==
var gphoto2_camera_8c =
[
    [ "_CameraPrivateCore", "struct__CameraPrivateCore.html", "struct__CameraPrivateCore" ],
    [ "_", "gphoto2-camera_8c.html#a32a3cf3d9dd914f5aeeca5423c157934", null ],
    [ "bindtextdomain", "gphoto2-camera_8c.html#add6dfc1077058ff26d79cdb18099d58a", null ],
    [ "CAMERA_UNUSED", "gphoto2-camera_8c.html#ac05b040056bfb8e0517570d4fd87eb1e", null ],
    [ "CHECK_CLOSE", "gphoto2-camera_8c.html#a8807273e062a649fe96c14f54e436bca", null ],
    [ "CHECK_INIT", "gphoto2-camera_8c.html#a8501471508eb438eb07e9cf034dc498c", null ],
    [ "CHECK_OPEN", "gphoto2-camera_8c.html#a4954f9a8b7eaf2df232babe91f93fca7", null ],
    [ "CHECK_RESULT_OPEN_CLOSE", "gphoto2-camera_8c.html#a2413621dbe10bd9d91fdd5fd82c81618", null ],
    [ "CR", "gphoto2-camera_8c.html#a7de1aba49ce9fb5d84464417da3352e6", null ],
    [ "CRS", "gphoto2-camera_8c.html#abe944d32d0d1d16ab7519111476a8b57", null ],
    [ "CRSL", "gphoto2-camera_8c.html#a7fb0a84c4d54825143b3eee22e81d3ce", null ],
    [ "dcgettext", "gphoto2-camera_8c.html#a115dd6a6dd9d7a249f6374a7c06deef5", null ],
    [ "dgettext", "gphoto2-camera_8c.html#ad24abc7110e1bdf384dc2ef2b63e5d07", null ],
    [ "gettext", "gphoto2-camera_8c.html#a83b8be0887dede025766d25e2bb884c6", null ],
    [ "N_", "gphoto2-camera_8c.html#a75278405e7f034d2b1af80bfd94675fe", null ],
    [ "textdomain", "gphoto2-camera_8c.html#a5f80e8482ab93869489531a8c7ce7006", null ],
    [ "gp_camera_autodetect", "gphoto2-camera_8c.html#ae7b6050bb4bc7a697f9e07253c27710f", null ],
    [ "gp_camera_capture", "gphoto2-camera_8c.html#a8fa6903e3bf0ab26edc4e915512aa44f", null ],
    [ "gp_camera_capture_preview", "gphoto2-camera_8c.html#accaa70d614800dac941e543187c9712d", null ],
    [ "gp_camera_exit", "gphoto2-camera_8c.html#a6f19c4ea385641fb972e779badf48ae1", null ],
    [ "gp_camera_file_delete", "gphoto2-camera_8c.html#a456172175ee1829ef172ee9c747e850d", null ],
    [ "gp_camera_file_get", "gphoto2-camera_8c.html#a262b1bc840d62b12605e3acc543f714d", null ],
    [ "gp_camera_file_get_info", "gphoto2-camera_8c.html#adda54321b1947b711d345936041f80c7", null ],
    [ "gp_camera_file_read", "gphoto2-camera_8c.html#a1c1ad4e0cc48fec22aaddbba147975c8", null ],
    [ "gp_camera_file_set_info", "gphoto2-camera_8c.html#a1a66b26a0456f3d265051c4018f67208", null ],
    [ "gp_camera_folder_delete_all", "gphoto2-camera_8c.html#a0c61c3d62a6bb6daecbadbffa06cf3fb", null ],
    [ "gp_camera_folder_list_files", "gphoto2-camera_8c.html#a0cdf2043359617d5132665c36fc557d0", null ],
    [ "gp_camera_folder_list_folders", "gphoto2-camera_8c.html#a7dc2b5ed66b61b881caf7436cb05ded0", null ],
    [ "gp_camera_folder_make_dir", "gphoto2-camera_8c.html#a6b6669216aeae67304649edd42db605d", null ],
    [ "gp_camera_folder_put_file", "gphoto2-camera_8c.html#aa3dd64d491735a55bcab15d41b9113c3", null ],
    [ "gp_camera_folder_remove_dir", "gphoto2-camera_8c.html#a11f3855eef4f009701b008908fc78608", null ],
    [ "gp_camera_free", "gphoto2-camera_8c.html#a78ae1a19cc0fb4d94026f82497381124", null ],
    [ "gp_camera_get_abilities", "gphoto2-camera_8c.html#a240f8cc35944b01cce71609c265fda3a", null ],
    [ "gp_camera_get_about", "gphoto2-camera_8c.html#a0a46cbd79e1a634acebec4380cee6c5b", null ],
    [ "gp_camera_get_config", "gphoto2-camera_8c.html#ae87f24abbc6ee895867331c64e6986cf", null ],
    [ "gp_camera_get_manual", "gphoto2-camera_8c.html#a32cfd1eaec837dd43676eb211fa68cdb", null ],
    [ "gp_camera_get_port_info", "gphoto2-camera_8c.html#a969c10fd16501f62f0e3a276d237764a", null ],
    [ "gp_camera_get_port_speed", "gphoto2-camera_8c.html#a068405c418270c7c63ab9fdc3c0ae620", null ],
    [ "gp_camera_get_single_config", "gphoto2-camera_8c.html#abf808fe8f9c7b0dbf9f9c4b6d5aef4b2", null ],
    [ "gp_camera_get_storageinfo", "gphoto2-camera_8c.html#ad5add695de4a33b6c5cbb8be32bf9af7", null ],
    [ "gp_camera_get_summary", "gphoto2-camera_8c.html#a7a2b16620e8dcd0efbd6f767188d9162", null ],
    [ "gp_camera_init", "gphoto2-camera_8c.html#ab0e3da4a22b7b71ec36e58157c868a9e", null ],
    [ "gp_camera_list_config", "gphoto2-camera_8c.html#a01d8d222d4b7f090f678080b8ce9998e", null ],
    [ "gp_camera_new", "gphoto2-camera_8c.html#ad89d6ee1c35f5ee399e89ecaeac6bd61", null ],
    [ "gp_camera_ref", "gphoto2-camera_8c.html#a449781f840d1a82e56f424d33371c511", null ],
    [ "gp_camera_set_abilities", "gphoto2-camera_8c.html#a95f595a6d9bfe68d99419a0087363f89", null ],
    [ "gp_camera_set_config", "gphoto2-camera_8c.html#a0b289e071be43bfeb6e65757cc274dbf", null ],
    [ "gp_camera_set_port_info", "gphoto2-camera_8c.html#a87bb8878064d7c4a98f1be7cedf7fd3c", null ],
    [ "gp_camera_set_port_speed", "gphoto2-camera_8c.html#a0fc2c594397f144a134074757e9dfab1", null ],
    [ "gp_camera_set_single_config", "gphoto2-camera_8c.html#ae231c37c434852418e308cda85f262e9", null ],
    [ "gp_camera_set_timeout_funcs", "gphoto2-camera_8c.html#af2e448cda5a2a1637d497fec7b89c44f", null ],
    [ "gp_camera_start_timeout", "gphoto2-camera_8c.html#a640b436ef19db8154283cc3044fb1d0a", null ],
    [ "gp_camera_stop_timeout", "gphoto2-camera_8c.html#a6d95c83814161ccd8f4cc1e86233c9d4", null ],
    [ "gp_camera_trigger_capture", "gphoto2-camera_8c.html#a5d5649f8c672a52800d0723bf29f33fa", null ],
    [ "gp_camera_unref", "gphoto2-camera_8c.html#a6027cb54859c035ce943cf1c3e06121a", null ],
    [ "gp_camera_wait_for_event", "gphoto2-camera_8c.html#a6a3aa30acd4bbe74087ce0fbcb9ea3a9", null ]
];
